# openapi-java-client

Signicat Sign REST API

- API version: v1

- Build date: 2020-08-07T11:38:01.533+02:00[Europe/Oslo]

Signicat's signature rest microservice

  For more information, please visit [https://developer.signicat.com/support/](https://developer.signicat.com/support/)

*Automatically generated by the [OpenAPI Generator](https://openapi-generator.tech)*

## Requirements

Building the API client library requires:

1. Java 1.8+
2. Maven/Gradle

## Installation

To install the API client library to your local Maven repository, simply execute:

```shell
mvn clean install
```

To deploy it to a remote Maven repository instead, configure the settings of the repository and execute:

```shell
mvn clean deploy
```

Refer to the [OSSRH Guide](http://central.sonatype.org/pages/ossrh-guide.html) for more information.

### Maven users

Add this dependency to your project's POM:

```xml
<dependency>
  <groupId>org.openapitools</groupId>
  <artifactId>openapi-java-client</artifactId>
  <version>v1</version>
  <scope>compile</scope>
</dependency>
```

### Gradle users

Add this dependency to your project's build file:

```groovy
compile "org.openapitools:openapi-java-client:v1"
```

### Others

At first generate the JAR by executing:

```shell
mvn clean package
```

Then manually install the following JARs:

- `target/openapi-java-client-v1.jar`
- `target/lib/*.jar`

## Getting Started

Please follow the [installation](#installation) instruction and execute the following Java code:

```java

import com.example.demo.signapi.client.invoker.*;
import com.example.demo.signapi.client.invoker.auth.*;
import com.example.demo.signapi.client.model.*;
import com.example.demo.signapi.client.api.ArchiveDocumentApi;

public class ArchiveDocumentApiExample {

    public static void main(String[] args) {
        ApiClient defaultClient = Configuration.getDefaultApiClient();
        defaultClient.setBasePath("http://Please select a server");
        
        // Configure OAuth2 access token for authorization: signrestOauth2Security
        OAuth signrestOauth2Security = (OAuth) defaultClient.getAuthentication("signrestOauth2Security");
        signrestOauth2Security.setAccessToken("YOUR ACCESS TOKEN");

        ArchiveDocumentApi apiInstance = new ArchiveDocumentApi(defaultClient);
        String archiveId = 200320193lrce4j85hpgdns4ivbuts5dy7pgarm1e0iozjq4qh2tey77jv; // String | The ID of the document stored in Signicat's document archive.
        try {
            File result = apiInstance.getArchiveDocument(archiveId);
            System.out.println(result);
        } catch (ApiException e) {
            System.err.println("Exception when calling ArchiveDocumentApi#getArchiveDocument");
            System.err.println("Status code: " + e.getCode());
            System.err.println("Reason: " + e.getResponseBody());
            System.err.println("Response headers: " + e.getResponseHeaders());
            e.printStackTrace();
        }
    }
}

```

## Documentation for API Endpoints

All URIs are relative to *http://Please select a server*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ArchiveDocumentApi* | [**getArchiveDocument**](docs/ArchiveDocumentApi.md#getArchiveDocument) | **GET** /archive-documents/{archiveId} | Get archived document
*DocumentApi* | [**deleteFileOnSds**](docs/DocumentApi.md#deleteFileOnSds) | **DELETE** /documents/{documentId} | Delete document
*DocumentApi* | [**getSdsDocument**](docs/DocumentApi.md#getSdsDocument) | **GET** /documents/{documentId} | Get document
*DocumentApi* | [**uploadFileToSds**](docs/DocumentApi.md#uploadFileToSds) | **POST** /documents | Upload session document
*SigningOrderApi* | [**createRequest**](docs/SigningOrderApi.md#createRequest) | **POST** /orders | Create signing order
*SigningOrderApi* | [**deleteSigningOrder**](docs/SigningOrderApi.md#deleteSigningOrder) | **DELETE** /orders/{orderId} | Delete signing order
*SigningOrderApi* | [**getGeneratedDocument**](docs/SigningOrderApi.md#getGeneratedDocument) | **GET** /orders/{orderId}/tasks/{taskId}/documents/{documentId}/generated | Get generated document
*SigningOrderApi* | [**getOriginalDocument**](docs/SigningOrderApi.md#getOriginalDocument) | **GET** /orders/{orderId}/tasks/{taskId}/documents/{documentId}/original | Get original document
*SigningOrderApi* | [**getResultDocument**](docs/SigningOrderApi.md#getResultDocument) | **GET** /orders/{orderId}/tasks/{taskId}/documents/{documentId}/result | Get signed document
*SigningOrderApi* | [**getResultDocument1**](docs/SigningOrderApi.md#getResultDocument1) | **GET** /orders/{orderId}/packaging-tasks/{packagingTaskId}/result | Get packaging task result document
*SigningOrderApi* | [**getStatus**](docs/SigningOrderApi.md#getStatus) | **GET** /orders/{orderId}/tasks/{taskId}/status | Get task status
*SigningOrderApi* | [**getStatus1**](docs/SigningOrderApi.md#getStatus1) | **GET** /orders/{orderId}/packaging-tasks/{packagingTaskId}/status | Get packaging task status
*SigningOrderApi* | [**getTaskEvents**](docs/SigningOrderApi.md#getTaskEvents) | **GET** /orders/{orderId}/tasks/{taskId}/events | Get a list of task events


## Documentation for Models

 - [Authentication](docs/Authentication.md)
 - [ClientProblem](docs/ClientProblem.md)
 - [Dialog](docs/Dialog.md)
 - [Document](docs/Document.md)
 - [DocumentRefId](docs/DocumentRefId.md)
 - [DocumentStatus](docs/DocumentStatus.md)
 - [Event](docs/Event.md)
 - [Form](docs/Form.md)
 - [FormParam](docs/FormParam.md)
 - [Method](docs/Method.md)
 - [PackagingTask](docs/PackagingTask.md)
 - [PackagingTaskDocument](docs/PackagingTaskDocument.md)
 - [PackagingTaskNotification](docs/PackagingTaskNotification.md)
 - [PackagingTaskSchedule](docs/PackagingTaskSchedule.md)
 - [PackagingTaskStatusInfo](docs/PackagingTaskStatusInfo.md)
 - [SigningOrder](docs/SigningOrder.md)
 - [SigningOrderNotification](docs/SigningOrderNotification.md)
 - [SigningOrderRefId](docs/SigningOrderRefId.md)
 - [Subject](docs/Subject.md)
 - [SubjectAttribute](docs/SubjectAttribute.md)
 - [Task](docs/Task.md)
 - [TaskNotification](docs/TaskNotification.md)
 - [TaskSchedule](docs/TaskSchedule.md)
 - [TaskScheduleDelay](docs/TaskScheduleDelay.md)
 - [TaskStatusInfo](docs/TaskStatusInfo.md)


## Documentation for Authorization

Authentication schemes defined for the API:
### signrestOauth2Security


- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
  - client.signature: Manage signing orders


## Recommendation

It's recommended to create an instance of `ApiClient` per thread in a multithreaded environment to avoid any potential issues.

## Author

support@signicat.com

